pub struct RoutingKeyMiddleware { /* private fields */ }Expand description
Middleware for dynamic routing key assignment.
Assigns routing keys to messages based on custom logic or message content. Useful for implementing dynamic routing strategies.
Examples
use celers_kombu::{RoutingKeyMiddleware, MessageMiddleware};
// Use task name as routing key
let middleware = RoutingKeyMiddleware::new(|msg| {
format!("tasks.{}", msg.headers.task)
});
assert_eq!(middleware.name(), "routing_key");Implementations
Sourceimpl RoutingKeyMiddleware
impl RoutingKeyMiddleware
Sourcepub fn new<F>(key_generator: F) -> Self
pub fn new<F>(key_generator: F) -> Self
Create a new routing key middleware with a custom key generator
Sourcepub fn from_task_name() -> Self
pub fn from_task_name() -> Self
Create a routing key from task name
Sourcepub fn from_task_and_priority() -> Self
pub fn from_task_and_priority() -> Self
Create a routing key from task name with priority